@@ -1,9 +1,10 @@
 ##Pre-loaded libraries and graphing functions to speed things up
 
 library("ggplot2")
-library("reshape")
 library("RColorBrewer")
 library("scales")
+library(dplyr)
+library(tidyr)
 
 source('graphs.R')
 source('tables.R')
