@@ -1,4 +1,4 @@
--- Copyright 2010, 2017 The Tor Project
+-- Copyright 2010, 2018 The Tor Project
 -- See LICENSE for licensing information
 
 CREATE LANGUAGE plpgsql;
@@ -151,29 +151,6 @@ CREATE TABLE relay_versions (
     CONSTRAINT relay_versions_pkey PRIMARY KEY(date, version)
 );
 
--- TABLE total_bandwidth
--- Contains information for the whole network's total bandwidth which is
--- used in the bandwidth graphs.
-CREATE TABLE total_bandwidth (
-    date DATE NOT NULL,
-    bwavg BIGINT NOT NULL,
-    bwburst BIGINT NOT NULL,
-    bwobserved BIGINT NOT NULL,
-    bwadvertised BIGINT NOT NULL,
-    CONSTRAINT total_bandwidth_pkey PRIMARY KEY(date)
-);
-
--- TABLE total_bwhist
--- Contains the total number of read/written and the number of dir bytes
--- read/written by all relays in the network on a given day. The dir bytes
--- are an estimate based on the subset of relays that count dir bytes.
-CREATE TABLE total_bwhist (
-    date DATE NOT NULL,
-    read BIGINT,
-    written BIGINT,
-    CONSTRAINT total_bwhist_pkey PRIMARY KEY(date)
-);
-
 -- TABLE bandwidth_flags
 CREATE TABLE bandwidth_flags (
     date DATE NOT NULL,
@@ -473,64 +450,6 @@ CREATE OR REPLACE FUNCTION refresh_relay_versions() RETURNS INTEGER AS $$
     END;
 $$ LANGUAGE plpgsql;
 
--- FUNCTION refresh_total_bandwidth()
--- This keeps the table total_bandwidth up-to-date when necessary.
-CREATE OR REPLACE FUNCTION refresh_total_bandwidth() RETURNS INTEGER AS $$
-    DECLARE
-        min_date TIMESTAMP WITHOUT TIME ZONE;
-        max_date TIMESTAMP WITHOUT TIME ZONE;
-    BEGIN
-
-    min_date := (SELECT MIN(date) FROM updates);
-    max_date := (SELECT MAX(date) + 1 FROM updates);
-
-    DELETE FROM total_bandwidth
-    WHERE date IN (SELECT date FROM updates);
-
-    EXECUTE '
-    INSERT INTO total_bandwidth
-    (bwavg, bwburst, bwobserved, bwadvertised, date)
-    SELECT (SUM(bandwidthavg)
-            / relay_statuses_per_day.count)::BIGINT AS bwavg,
-        (SUM(bandwidthburst)
-            / relay_statuses_per_day.count)::BIGINT AS bwburst,
-        (SUM(bandwidthobserved)
-            / relay_statuses_per_day.count)::BIGINT AS bwobserved,
-        (SUM(LEAST(bandwidthavg, bandwidthobserved))
-            / relay_statuses_per_day.count)::BIGINT AS bwadvertised,
-        DATE(validafter)
-    FROM descriptor RIGHT JOIN statusentry
-    ON descriptor.descriptor = statusentry.descriptor
-    JOIN relay_statuses_per_day
-    ON DATE(validafter) = relay_statuses_per_day.date
-    WHERE isrunning = TRUE
-          AND validafter >= ''' || min_date || '''
-          AND validafter < ''' || max_date || '''
-          AND DATE(validafter) IN (SELECT date FROM updates)
-          AND relay_statuses_per_day.date >= ''' || min_date || '''
-          AND relay_statuses_per_day.date < ''' || max_date || '''
-          AND DATE(relay_statuses_per_day.date) IN
-              (SELECT date FROM updates)
-    GROUP BY DATE(validafter), relay_statuses_per_day.count';
-
-    RETURN 1;
-    END;
-$$ LANGUAGE plpgsql;
-
-CREATE OR REPLACE FUNCTION refresh_total_bwhist() RETURNS INTEGER AS $$
-  BEGIN
-  DELETE FROM total_bwhist WHERE date IN (SELECT date FROM updates);
-  INSERT INTO total_bwhist (date, read, written)
-  SELECT date, SUM(read_sum) AS read, SUM(written_sum) AS written
-  FROM bwhist
-  WHERE date >= (SELECT MIN(date) FROM updates)
-  AND date <= (SELECT MAX(date) FROM updates)
-  AND date IN (SELECT date FROM updates)
-  GROUP BY date;
-  RETURN 1;
-  END;
-$$ LANGUAGE plpgsql;
-
 CREATE OR REPLACE FUNCTION refresh_bandwidth_flags() RETURNS INTEGER AS $$
     DECLARE
         min_date TIMESTAMP WITHOUT TIME ZONE;
@@ -693,12 +612,8 @@ CREATE OR REPLACE FUNCTION refresh_all() RETURNS INTEGER AS $$
     RAISE NOTICE '% Refreshing relay versions.', timeofday();
     PERFORM refresh_relay_versions();
     RAISE NOTICE '% Refreshing total relay bandwidth.', timeofday();
-    PERFORM refresh_total_bandwidth();
-    RAISE NOTICE '% Refreshing relay bandwidth history.', timeofday();
-    PERFORM refresh_total_bwhist();
-    RAISE NOTICE '% Refreshing total relay bandwidth by flags.', timeofday();
     PERFORM refresh_bandwidth_flags();
-    RAISE NOTICE '% Refreshing bandwidth history by flags.', timeofday();
+    RAISE NOTICE '% Refreshing bandwidth history.', timeofday();
     PERFORM refresh_bwhist_flags();
     RAISE NOTICE '% Refreshing user statistics.', timeofday();
     PERFORM refresh_user_stats();
@@ -720,7 +635,7 @@ CREATE VIEW stats_servers AS
   (SELECT date, NULL AS flag, NULL AS country, NULL AS version,
   NULL AS platform, TRUE AS ec2bridge, NULL AS relays,
   avg_running_ec2 AS bridges FROM bridge_network_size
-  WHERE date < current_date - 1)
+  WHERE date < current_date)
 UNION ALL
   (SELECT COALESCE(network_size.date, bridge_network_size.date) AS date,
   NULL AS flag, NULL AS country, NULL AS version, NULL AS platform,
@@ -729,57 +644,57 @@ UNION ALL
   FULL OUTER JOIN bridge_network_size
   ON network_size.date = bridge_network_size.date
   WHERE COALESCE(network_size.date, bridge_network_size.date) <
-  current_date - 1)
+  current_date)
 UNION ALL
   (SELECT date, 'Exit' AS flag, NULL AS country, NULL AS version,
   NULL AS platform, NULL AS ec2bridge, avg_exit AS relays,
-  NULL AS bridges FROM network_size WHERE date < current_date - 1)
+  NULL AS bridges FROM network_size WHERE date < current_date)
 UNION ALL
   (SELECT date, 'Guard' AS flag, NULL AS country, NULL AS version,
   NULL AS platform, NULL AS ec2bridge, avg_guard AS relays,
-  NULL AS bridges FROM network_size WHERE date < current_date - 1)
+  NULL AS bridges FROM network_size WHERE date < current_date)
 UNION ALL
   (SELECT date, 'Fast' AS flag, NULL AS country, NULL AS version,
   NULL AS platform, NULL AS ec2bridge, avg_fast AS relays,
-  NULL AS bridges FROM network_size WHERE date < current_date - 1)
+  NULL AS bridges FROM network_size WHERE date < current_date)
 UNION ALL
   (SELECT date, 'Stable' AS flag, NULL AS country, NULL AS version,
   NULL AS platform, NULL AS ec2bridge, avg_stable AS relays,
-  NULL AS bridges FROM network_size WHERE date < current_date - 1)
+  NULL AS bridges FROM network_size WHERE date < current_date)
 UNION ALL
   (SELECT date, 'HSDir' AS flag, NULL AS country, NULL AS version,
   NULL AS platform, NULL AS ec2bridge, avg_hsdir AS relays,
-  NULL AS bridges FROM network_size WHERE date < current_date - 1)
+  NULL AS bridges FROM network_size WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, CASE WHEN country != 'zz' THEN country
   ELSE '??' END AS country, NULL AS version, NULL AS platform,
   NULL AS ec2bridge, relays, NULL AS bridges FROM relay_countries
-  WHERE date < current_date - 1)
+  WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, NULL AS country, version, NULL AS platform,
   NULL AS ec2bridge, relays, NULL AS bridges FROM relay_versions
-  WHERE date < current_date - 1)
+  WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, NULL AS country, NULL AS version,
   'Linux' AS platform, NULL AS ec2bridge, avg_linux AS relays,
-  NULL AS bridges FROM relay_platforms WHERE date < current_date - 1)
+  NULL AS bridges FROM relay_platforms WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, NULL AS country, NULL AS version,
   'Darwin' AS platform, NULL AS ec2bridge, avg_darwin AS relays,
-  NULL AS bridges FROM relay_platforms WHERE date < current_date - 1)
+  NULL AS bridges FROM relay_platforms WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, NULL AS country, NULL AS version,
   'BSD' AS platform, NULL AS ec2bridge, avg_bsd AS relays,
-  NULL AS bridges FROM relay_platforms WHERE date < current_date - 1)
+  NULL AS bridges FROM relay_platforms WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, NULL AS country, NULL AS version,
   'Windows' AS platform, NULL AS ec2bridge, avg_windows AS relays,
-  NULL AS bridges FROM relay_platforms WHERE date < current_date - 1)
+  NULL AS bridges FROM relay_platforms WHERE date < current_date)
 UNION ALL
   (SELECT date, NULL AS flag, NULL AS country, NULL AS version,
   'Other' AS platform, NULL AS ec2bridge, avg_other AS relays,
-  NULL AS bridges FROM relay_platforms WHERE date < current_date - 1)
-ORDER BY 1, 2, 3, 4, 5, 6;
+  NULL AS bridges FROM relay_platforms WHERE date < current_date)
+ORDER BY date, flag, country, version, platform, ec2bridge;
 
 -- View for exporting bandwidth statistics.
 CREATE VIEW stats_bandwidth AS
@@ -797,27 +712,14 @@ CREATE VIEW stats_bandwidth AS
   AND bandwidth_flags.isexit = bwhist_flags.isexit
   AND bandwidth_flags.isguard = bwhist_flags.isguard
   WHERE COALESCE(bandwidth_flags.date, bwhist_flags.date) <
-  current_date - 3)
+  current_date - 2)
 UNION ALL
-  (SELECT COALESCE(total_bandwidth.date, total_bwhist.date, u.date)
-  AS date, NULL AS isexit, NULL AS isguard,
-  total_bandwidth.bwadvertised AS advbw,
-  CASE WHEN total_bwhist.read IS NOT NULL
-  THEN total_bwhist.read / 86400 END AS bwread,
-  CASE WHEN total_bwhist.written IS NOT NULL
-  THEN total_bwhist.written / 86400 END AS bwwrite,
-  CASE WHEN u.date IS NOT NULL
-  THEN FLOOR(CAST(u.dr AS NUMERIC) * CAST(u.brp AS NUMERIC) /
-  CAST(u.brd AS NUMERIC) / CAST(86400 AS NUMERIC)) END AS dirread,
-  CASE WHEN u.date IS NOT NULL
-  THEN FLOOR(CAST(u.dw AS NUMERIC) * CAST(u.bwp AS NUMERIC) /
-  CAST(u.bwd AS NUMERIC) / CAST(86400 AS NUMERIC)) END AS dirwrite
-  FROM total_bandwidth FULL OUTER JOIN total_bwhist
-  ON total_bandwidth.date = total_bwhist.date
-  FULL OUTER JOIN (SELECT * FROM user_stats WHERE country = 'zy'
-  AND bwp / bwd <= 3) u
-  ON COALESCE(total_bandwidth.date, total_bwhist.date) = u.date
-  WHERE COALESCE(total_bandwidth.date, total_bwhist.date, u.date) <
-  current_date - 3)
-ORDER BY 1, 2, 3;
+  (SELECT date, NULL AS isexit, NULL AS isguard, NULL AS advbw,
+  NULL AS bwread, NULL AS bwwrite,
+  FLOOR(CAST(dr AS NUMERIC) / CAST(86400 AS NUMERIC)) AS dirread,
+  FLOOR(CAST(dw AS NUMERIC) / CAST(86400 AS NUMERIC)) AS dirwrite
+  FROM user_stats
+  WHERE country = 'zy'
+  AND date < current_date - 2)
+ORDER BY date, isexit, isguard;
 
